@@ -1,22 +1,22 @@
+import os
+
 import cachecontrol
 import google.auth.transport.requests
 import requests
 from flask import request
 from google.oauth2 import id_token
 
+from cirrocumulus.envir import CIRRO_AUTH_CLIENT_ID
+
 
 class GoogleAuth:
 
-    def __init__(self, clientId):
+    def __init__(self):
         session = requests.session()
-        self.clientId = clientId
+        self.client_id = os.environ.get(CIRRO_AUTH_CLIENT_ID)
         cached_session = cachecontrol.CacheControl(session)
         self.cached_request = google.auth.transport.requests.Request(session=cached_session)
 
-    @property
-    def client_id(self):
-        return self.clientId
-
     def auth(self):
         token = request.headers.get('Authorization')
         if token is not None:
@@ -25,8 +25,8 @@ class GoogleAuth:
             token = token.split('Bearer ')[1]
         else:
             token = request.args.get('access_token')
-        idinfo = id_token.verify_oauth2_token(token, self.cached_request, self.clientId)
-        if idinfo['aud'] != self.clientId:
+        idinfo = id_token.verify_oauth2_token(token, self.cached_request, self.client_id)
+        if idinfo['aud'] != self.client_id:
             raise ValueError('Wrong aud')
         if idinfo['iss'] not in ['accounts.google.com', 'https://accounts.google.com']:
             raise ValueError('Wrong issuer.')
