@@ -6,13 +6,17 @@ import anndata
 import numpy as np
 import pandas as pd
 import scipy.sparse
-from cirrocumulus.anndata_util import get_scanpy_marker_keys, dataset_schema, ADATA_MODULE_UNS_KEY
-from cirrocumulus.io_util import get_markers, filter_markers, add_spatial, SPATIAL_HELP, unique_id
-from cirrocumulus.util import to_json, get_fs, open_file
+
+from cirrocumulus.anndata_util import ADATA_MODULE_UNS_KEY, dataset_schema, \
+    get_scanpy_marker_keys
+from cirrocumulus.io_util import SPATIAL_HELP, add_spatial, filter_markers, \
+    get_markers, unique_id
+from cirrocumulus.util import get_fs, open_file, to_json
 
 logger = logging.getLogger("cirro")
 
-cluster_fields = ['anno', 'cell_type', 'celltype', 'leiden', 'louvain', 'seurat_cluster', 'cluster']
+cluster_fields = ['anno', 'cell_type', 'celltype', 'leiden', 'louvain',
+                  'seurat_cluster', 'cluster']
 categorical_fields_convert = ['seurat_clusters']
 
 
@@ -24,18 +28,22 @@ def read_adata(path, spatial_directory=None, use_raw=False):
     else:
         adata = anndata.read(path)
     if 'module' in adata.uns:
-        adata.uns[ADATA_MODULE_UNS_KEY] = anndata.AnnData(X=adata.uns['module']['X'],
-                                                          var=adata.uns['module']['var'])
-    if use_raw and adata.raw is not None and adata.shape[0] == adata.raw.shape[0]:
+        adata.uns[ADATA_MODULE_UNS_KEY] = anndata.AnnData(
+            X=adata.uns['module']['X'],
+            var=adata.uns['module']['var'])
+    if use_raw and adata.raw is not None and adata.shape[0] == adata.raw.shape[
+        0]:
         logger.info('Using adata.raw')
-        adata = anndata.AnnData(X=adata.raw.X, var=adata.raw.var, obs=adata.obs, obsm=adata.obsm, uns=adata.uns)
+        adata = anndata.AnnData(X=adata.raw.X, var=adata.raw.var, obs=adata.obs,
+                                obsm=adata.obsm, uns=adata.uns)
 
     if spatial_directory is not None:
         if not add_spatial(adata, spatial_directory):
             logger.info('No spatial data found in {}'.format(spatial_directory))
 
     for field in categorical_fields_convert:
-        if field in adata.obs and not pd.api.types.is_categorical_dtype(adata.obs[field]):
+        if field in adata.obs and not pd.api.types.is_categorical_dtype(
+                adata.obs[field]):
             logger.info('Converting {} to categorical'.format(field))
             adata.obs[field] = adata.obs[field].astype(str).astype('category')
     return adata
@@ -43,8 +51,10 @@ def read_adata(path, spatial_directory=None, use_raw=False):
 
 class PrepareData:
 
-    def __init__(self, datasets, output, dimensions=None, groups=[], group_nfeatures=10, markers=[],
-                 output_format='parquet', no_auto_groups=False, save_whitelist=None):
+    def __init__(self, datasets, output, dimensions=None, groups=[],
+                 group_nfeatures=10, markers=[],
+                 output_format='parquet', no_auto_groups=False,
+                 save_whitelist=None):
         self.groups = groups
         self.group_nfeatures = group_nfeatures
         self.markers = markers
@@ -62,10 +72,14 @@ class PrepareData:
             for i in range(len(datasets)):
                 dataset = datasets[i]
                 if 'group' not in dataset.var:
-                    dataset.var['group'] = dataset.uns.get('name', 'dataset {}'.format(i + 1))
-                if i > 0 and not np.array_equal(datasets[0].obs.index, dataset.obs.index):
+                    dataset.var['group'] = dataset.uns.get('name',
+                                                           'dataset {}'.format(
+                                                               i + 1))
+                if i > 0 and not np.array_equal(datasets[0].obs.index,
+                                                dataset.obs.index):
                     raise ValueError('obs ids are not equal')
-            dataset = anndata.concat(datasets, axis=1, label='group', merge='unique')
+            dataset = anndata.concat(datasets, axis=1, label='group',
+                                     merge='unique')
         else:
             dataset = datasets[0]
         dataset.var.index = dataset.var.index.str.replace('/', '_')
@@ -78,7 +92,8 @@ class PrepareData:
         self.measures = []
         self.others = []
         self.dataset = dataset
-        if scipy.sparse.issparse(dataset.X) and not scipy.sparse.isspmatrix_csc(dataset.X):
+        if scipy.sparse.issparse(dataset.X) and not scipy.sparse.isspmatrix_csc(
+                dataset.X):
             dataset.X = dataset.X.tocsc()
         for i in range(len(dataset.obs.columns)):
             name = dataset.obs.columns[i]
@@ -96,7 +111,8 @@ class PrepareData:
                         dataset.obs[name] = dataset.obs[name].astype('category')
                 else:
                     self.others.append(name)
-            elif not pd.api.types.is_string_dtype(c) and not pd.api.types.is_object_dtype(c):
+            elif not pd.api.types.is_string_dtype(
+                    c) and not pd.api.types.is_object_dtype(c):
                 self.measures.append('obs/' + name)
             else:
                 self.others.append(name)
@@ -116,7 +132,8 @@ class PrepareData:
             for field in dataset.obs.columns:
                 field_lc = field.lower()
                 for cluster_field in cluster_fields:
-                    if field_lc.find(cluster_field) != -1 and cluster_field not in existing_fields:
+                    if field_lc.find(
+                            cluster_field) != -1 and cluster_field not in existing_fields:
                         groups.append(field)
                         break
             self.groups = groups
@@ -135,8 +152,9 @@ class PrepareData:
                 except ModuleNotFoundError:
                     pass
             if not use_pegasus and not use_scanpy:
-                raise ValueError('Please install pegasuspy or scanpy to compute markers')
-
+                raise ValueError(
+                    'Please install pegasuspy or scanpy to compute markers')
+            first_time = True
             for group in self.groups:
                 field = group
                 if group not in dataset.obs:  # test if multiple comma separated fields
@@ -148,21 +166,41 @@ class PrepareData:
                                 use_split_groups = False
                                 break
                         if use_split_groups:
-                            dataset.obs[field] = dataset.obs[split_groups[0]].str.cat(dataset.obs[split_groups[1:]],
-                                                                                      sep=',')
+                            dataset.obs[field] = dataset.obs[
+                                split_groups[0]].str.cat(
+                                dataset.obs[split_groups[1:]],
+                                sep=',')
 
                 if field in dataset.obs:
-                    if not pd.api.types.is_categorical_dtype(dataset.obs[field]):
-                        dataset.obs[field] = dataset.obs[field].astype(str).astype('category')
+                    if not pd.api.types.is_categorical_dtype(
+                            dataset.obs[field]):
+                        dataset.obs[field] = dataset.obs[field].astype(
+                            str).astype('category')
                     if len(dataset.obs[field].cat.categories) > 1:
-                        logger.info('Computing markers for {}'.format(field))
+
                         key_added = 'rank_genes_' + str(field)
-                        if use_pegasus:
-                            pg.de_analysis(dataset, cluster=field, de_key=key_added)
-                        else:
-                            sc.tl.rank_genes_groups(dataset, field, key_added=key_added, method='t-test')
+                        value_counts = dataset.obs[field].value_counts()
+                        filtered_value_counts = value_counts[value_counts >= 3]
+                        if len(filtered_value_counts) >= 2:
+                            if first_time:
+                                logger.info(
+                                    'Using {} to compute markers'.format(
+                                        'pegasuspy' if use_pegasus else 'scanpy'))
+                                first_time = False
+                            logger.info(
+                                'Computing markers for {}'.format(field))
+                            if use_pegasus:
+                                pg.de_analysis(dataset, cluster=field,
+                                               de_key=key_added,
+                                               subset=filtered_value_counts.index.to_list())
+                            else:
+                                sc.tl.rank_genes_groups(dataset, field,
+                                                        key_added=key_added,
+                                                        method='t-test',
+                                                        groups=filtered_value_counts.index.to_list())
                 else:
-                    logger.info(group + ' not found in ' + ', '.join(dataset.obs.columns))
+                    logger.info(group + ' not found in ' + ', '.join(
+                        dataset.obs.columns))
         schema = self.get_schema()
         schema['format'] = output_format
         if output_format in ['parquet', 'zarr']:
@@ -182,13 +220,18 @@ class PrepareData:
                 full_result = results[i]
                 result_id = full_result.pop('id')
                 # keep id, name, type in schema, store rest externally
-                results[i] = dict(id=result_id, name=full_result.pop('name'), type=full_result.pop('type'),
-                                  content_type='application/json', content_encoding='gzip' if is_gzip else None)
+                results[i] = dict(id=result_id, name=full_result.pop('name'),
+                                  type=full_result.pop('type'),
+                                  content_type='application/json',
+                                  content_encoding='gzip' if is_gzip else None)
                 json_result = to_json(full_result)
 
-                result_path = os.path.join(uns_dir, result_id + '.json.gz') if is_gzip else os.path.join(uns_dir,
-                                                                                                             result_id + '.json')
-                with open_file(result_path, 'wt', compression='gzip' if is_gzip else None) as out:
+                result_path = os.path.join(uns_dir,
+                                           result_id + '.json.gz') if is_gzip else os.path.join(
+                    uns_dir,
+                    result_id + '.json')
+                with open_file(result_path, 'wt',
+                               compression='gzip' if is_gzip else None) as out:
                     out.write(json_result)
         images = dataset.uns.get('images')
         if images is not None:
@@ -202,13 +245,16 @@ class PrepareData:
 
         if output_format == 'parquet':
             from cirrocumulus.parquet_output import save_dataset_pq
-            save_dataset_pq(dataset, schema, self.base_output, filesystem, self.save_whitelist)
+            save_dataset_pq(dataset, schema, self.base_output, filesystem,
+                            self.save_whitelist)
         elif output_format == 'jsonl':
             from cirrocumulus.jsonl_io import save_dataset_jsonl
-            save_dataset_jsonl(dataset, schema, output_dir, self.base_output, filesystem)
+            save_dataset_jsonl(dataset, schema, output_dir, self.base_output,
+                               filesystem)
         elif output_format == 'zarr':
             from cirrocumulus.zarr_output import save_dataset_zarr
-            save_dataset_zarr(dataset, schema, self.base_output, filesystem, self.save_whitelist)
+            save_dataset_zarr(dataset, schema, self.base_output, filesystem,
+                              self.save_whitelist)
         else:
             raise ValueError("Unknown format")
 
@@ -232,9 +278,11 @@ class PrepareData:
 def main(argsv):
     parser = argparse.ArgumentParser(
         description='Prepare a dataset for cirrocumulus server.')
-    parser.add_argument('dataset', help='Path to a h5ad, loom, or Seurat file', nargs='+')
+    parser.add_argument('dataset', help='Path to a h5ad, loom, or Seurat file',
+                        nargs='+')
     parser.add_argument('--out', help='Path to output directory')
-    parser.add_argument('--format', help='Output format', choices=['parquet', 'jsonl', 'zarr'],
+    parser.add_argument('--format', help='Output format',
+                        choices=['parquet', 'jsonl', 'zarr'],
                         default='zarr')
     parser.add_argument('--whitelist',
                         help='Optional whitelist of fields to save. Only applies when output format is parquet',
@@ -249,11 +297,14 @@ def main(argsv):
     parser.add_argument('--groups',
                         help='List of groups to compute markers for (e.g. louvain). Markers created with cumulus/scanpy are automatically included. Separate multiple groups with a comma to combine groups using "AND" logic (e.g. louvain,day)',
                         action='append')
-    parser.add_argument('--group_nfeatures', help='Number of marker genes/features to include', type=int, default=10)
+    parser.add_argument('--group_nfeatures',
+                        help='Number of marker genes/features to include',
+                        type=int, default=10)
     parser.add_argument('--spatial', help=SPATIAL_HELP)
     args = parser.parse_args(argsv)
     logger.setLevel(logging.INFO)
     logger.addHandler(logging.StreamHandler())
+
     out = args.out
     no_auto_groups = args.no_auto_groups
     save_whitelist = args.whitelist
@@ -263,7 +314,8 @@ def main(argsv):
         out = os.path.splitext(os.path.basename(input_datasets[0]))[0]
     if out.endswith('/'):
         out = out[:len(out) - 1]
-    output_format2extension = dict(parquet='.cpq', jsonl='.jsonl', zarr='.zarr', h5ad='.h5ad')
+    output_format2extension = dict(parquet='.cpq', jsonl='.jsonl', zarr='.zarr',
+                                   h5ad='.h5ad')
     if not out.lower().endswith(output_format2extension[output_format]):
         out += output_format2extension[output_format]
 
@@ -279,18 +331,25 @@ def main(argsv):
             _, h5_file = tempfile.mkstemp(suffix='.h5ad')
             os.remove(h5_file)
             subprocess.check_call(
-                ['Rscript', pkg_resources.resource_filename("cirrocumulus", 'seurat2h5ad.R'), input_dataset, h5_file])
+                ['Rscript', pkg_resources.resource_filename("cirrocumulus",
+                                                            'seurat2h5ad.R'),
+                 input_dataset, h5_file])
             input_dataset = h5_file
             tmp_file = h5_file
             use_raw = True
             tmp_files.append(tmp_file)
-        adata = read_adata(input_dataset, spatial_directory=args.spatial, use_raw=use_raw)
+        adata = read_adata(input_dataset, spatial_directory=args.spatial,
+                           use_raw=use_raw)
         datasets.append(adata)
-        adata.uns['name'] = os.path.splitext(os.path.basename(input_dataset.rstrip('/')))[0]
+        adata.uns['name'] = \
+            os.path.splitext(os.path.basename(input_dataset.rstrip('/')))[0]
 
-    prepare_data = PrepareData(datasets=datasets, output=out, dimensions=args.groups, groups=args.groups,
+    prepare_data = PrepareData(datasets=datasets, output=out,
+                               dimensions=args.groups, groups=args.groups,
                                group_nfeatures=args.group_nfeatures,
-                               markers=args.markers, output_format=output_format, no_auto_groups=no_auto_groups,
+                               markers=args.markers,
+                               output_format=output_format,
+                               no_auto_groups=no_auto_groups,
                                save_whitelist=save_whitelist)
     prepare_data.execute()
     for tmp_file in tmp_files:
